==> atajo-ionic-0.0.15.tgz: package/src/lib/device/index.ts <==
import { Injectable } from '@angular/core';
import { Platform } from 'ionic-angular';
import { Device as IonicDevice } from '@ionic-native/device';
import { BatteryStatus, BatteryStatusResponse } from '@ionic-native/battery-status';
import { AppVersion } from '@ionic-native/app-version';

import 'rxjs/add/operator/map';

import { iDevice } from '../models/device';
import { Utils } from '../utils';

class DeviceMock extends IonicDevice {

    private identifier: string;

    constructor(private browser: any) {
        super();
        this.browser = browser;

    }

    get uuid(): string {
        return this.browser.uuid;
    }

    get platform(): string {
        return this.browser.appName;
    }

    get version(): string {
        return this.browser.fullVersion;
    }

    get manufacturer(): string {
        return this.browser.name;
    }

    get model(): string {
        return '';
    }

    get cordova(): string {
        return null;
    }

    get serial(): string {
        return '';
    }

}

class AppVersionMock {

    constructor() { }

    getAppName() { return new Promise(resolve => { resolve('webapp'); }); }
    getPackageName() { return new Promise(resolve => { resolve('N/A'); }); }
    getVersionCode() { return new Promise(resolve => { resolve('N/A'); }); }
    getVersionNumber() { return new Promise(resolve => { resolve('N/A'); }); }

}



@Injectable()
export class Device {

    interface: iDevice;
    device: IonicDevice;
    battery: object;

    constructor(public plt: Platform, private utils: Utils, private batteryStatus: BatteryStatus, private appVersion: AppVersion) {

        console.log("DEVICE INIT - IS CORDOVA " + plt.is('cordova'));
        this.device = plt.is('cordova') ? new IonicDevice() : new DeviceMock(utils.getBrowserFingerprint());
        this.appVersion = plt.is('cordova') ? appVersion : new AppVersionMock();
        this.battery = { level: 'unknown', isCharging: 'unknown' };

        let subscription = this.batteryStatus.onChange().subscribe(
            (status: BatteryStatusResponse) => {
                console.log("BATTERY STATUS UPDATE: " + status.level, status.isPlugged);
                this.battery = { level: status.level, isCharging: status.isPlugged }
            }
        );


    }

    public platform(): string { return this.device.platform.toLowerCase(); }
    public uuid(): string { return this.device.uuid.toLowerCase(); }

    public getDevice(): Promise<iDevice> {

        return new Promise((resolve, reject) => {


            Promise.all([
                this.appVersion.getAppName(),
                this.appVersion.getPackageName(),
                this.appVersion.getVersionCode(),
                this.appVersion.getVersionNumber()
            ]).then((config) => {

                console.log("BATTERY IS: ", this.battery);

                let appName = config[0] + "";
                let packageName = config[1] + "";
                let versionCode = config[2] + "";
                let versionNumber = config[3] + "";

                this.interface =
                    {
                        uuid: this.device.uuid,
                        platform: this.getPlatformFromAgent(),
                        version: this.device.version,
                        manufacturer: this.device.manufacturer,
                        model: this.device.model,
                        cordova: this.device.cordova,
                        serial: this.device.serial,
                        battery: this.battery,
                        signal: "0",
                        network: "unknown",
                        appName: appName,
                        packageName: packageName,
                        versionCode: versionCode,
                        versionNumber: versionNumber
                    }



                console.log("DEVICE IS : ", this.interface);
                resolve(this.interface);


            });




        })





    }

    public isCordova() {

        return this.plt.is('cordova');

    }

    public getPlatformFromAgent() {

        if (!document.URL.startsWith('http') || !document.URL.startsWith('https')) {
            return "web";
        }

        if (this.plt.is('windows')) {
            return "windows";
        }

        if (this.plt.is('android')) {
            return "android";
        }

        if (this.plt.is('ios')) {
            return "ios";
        }

        return "unknown";
    }


}

==> atajo-ionic-0.0.33.tgz: package/src/lib/device/index.ts <==
import { Injectable } from '@angular/core';
import { Platform } from 'ionic-angular';
import { Device as IonicDevice } from '@ionic-native/device';
import { BatteryStatus, BatteryStatusResponse } from '@ionic-native/battery-status';
import { AppVersion } from '@ionic-native/app-version';

import 'rxjs/add/operator/map';

import { iDevice } from '../models/device';
import { Utils } from '../utils';

class DeviceMock extends IonicDevice {

    private identifier: string;

    constructor(private browser: any) {
        super();
        this.browser = browser;

    }

    get uuid(): string {
        return this.browser.uuid;
    }

    get platform(): string {
        return this.browser.appName;
    }

    get version(): string {
        return this.browser.fullVersion;
    }

    get manufacturer(): string {
        return this.browser.name;
    }

    get model(): string {
        return '';
    }

    get cordova(): string {
        return null;
    }

    get serial(): string {
        return '';
    }

}

class AppVersionMock {

    constructor() { }

    getAppName() { return new Promise(resolve => { resolve('webapp'); }); }
    getPackageName() { return new Promise(resolve => { resolve('N/A'); }); }
    getVersionCode() { return new Promise(resolve => { resolve('N/A'); }); }
    getVersionNumber() { return new Promise(resolve => { resolve('N/A'); }); }

}



@Injectable()
export class Device {

    interface: iDevice;
    device: IonicDevice;
    battery: object;

    constructor(public plt: Platform, private utils: Utils, private batteryStatus: BatteryStatus, private appVersion: AppVersion) {

        console.log("DEVICE INIT - IS CORDOVA " + plt.is('cordova'));
        this.device = plt.is('cordova') ? new IonicDevice() : new DeviceMock(utils.getBrowserFingerprint());
        this.appVersion = plt.is('cordova') ? appVersion : new AppVersionMock();
        this.battery = { level: 'unknown', isCharging: 'unknown' };

        let subscription = this.batteryStatus.onChange().subscribe(
            (status: BatteryStatusResponse) => {
                console.log("BATTERY STATUS UPDATE: " + status.level, status.isPlugged);
                this.battery = { level: status.level, isCharging: status.isPlugged }
            }
        );


    }

    public platform(): string { return this.device.platform.toLowerCase(); }
    public uuid(): string { return this.device.uuid.toLowerCase(); }

    public getDevice(): Promise<iDevice> {

        return new Promise((resolve, reject) => {


            Promise.all([
                this.appVersion.getAppName(),
                this.appVersion.getPackageName(),
                this.appVersion.getVersionCode(),
                this.appVersion.getVersionNumber()
            ]).then((config) => {

                console.log("BATTERY IS: ", this.battery);

                let appName = config[0] + "";
                let packageName = config[1] + "";
                let versionCode = config[2] + "";
                let versionNumber = config[3] + "";

                this.interface =
                    {
                        uuid: this.device.uuid,
                        platform: this.getPlatformFromAgent(),
                        version: this.device.version,
                        manufacturer: this.device.manufacturer,
                        model: this.device.model,
                        cordova: this.device.cordova,
                        serial: this.device.serial,
                        battery: this.battery,
                        signal: "0",
                        network: "unknown",
                        appName: appName,
                        packageName: packageName,
                        versionCode: versionCode,
                        versionNumber: versionNumber
                    }



                console.log("DEVICE IS : ", this.interface);
                resolve(this.interface);


            });




        })





    }

    public isCordova() {

        return this.plt.is('cordova');

    }

    public getPlatformFromAgent() {

        if (document.URL.startsWith('http') || document.URL.startsWith('https')) {
            return "web";
        }

        if (this.plt.is('windows')) {
            return "windows";
        }

        if (this.plt.is('android')) {
            return "android";
        }

        if (this.plt.is('ios')) {
            return "ios";
        }

        return "unknown";
    }


}
